EventContext class

Implemented types

Constructors

EventContext({required String? appAuthToken, required String deviceId, required String sessionId, Map<String, dynamic>? networkHeaders})

Properties

appAuthToken String?
final
deviceId String
final
hashCode int
The hash code for this object.
no setterinherited
networkHeaders Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited