PulseEventsSdk class
Constructors
- PulseEventsSdk({required String appId, required EventContext eventContext})
Properties
- appId → String
-
final
- eventContext → EventContext
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
init(
{required String baseUrl, required String configUrlEndpoint, required PulseEventsSdkConfig config, bool debugMode = false}) → Future< bool> -
logout(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
refreshEventContext(
EventContext eventContext) → void -
setUserId(
String userId) → void -
toString(
) → String -
A string representation of this object.
inherited
-
trackEvent(
{required String eventName, required Map< String, dynamic> payload, int priority = 1}) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited