PulseEventsSdkConfig class
Constructors
- PulseEventsSdkConfig({String? fallbackEventPublishEndpoint, int defaultEventPriority = 1, String logSourceName = "PulseSDK", Duration eventSyncNetworkTimeout = const Duration(seconds: 10), int largestBatchSize = 100, Duration workerRetryPeriod = const Duration(seconds: 10), Duration syncRetryDelayDuration = kDebugMode ? const Duration(seconds: 5) : const Duration(seconds: 10), int maxDbSizeInMb = 10, bool shouldUseLocalConfigAsFallback = true})
Properties
- defaultEventPriority → int
-
final
- eventSyncNetworkTimeout → Duration
-
final
- fallbackEventPublishEndpoint → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- largestBatchSize → int
-
final
- logSourceName → String
-
final
- maxDbSizeInMb → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shouldUseLocalConfigAsFallback → bool
-
final
- syncMaxRetry → int
-
final
- syncRetryDelayDuration → Duration
-
final
- workerRetryPeriod → Duration
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited